.. _head_pose.angular_velocity:

Head Angular Velocity
=====================

.. automodule:: eyetrace.head_pose.angular_velocity
   :members:
   :undoc-members:
   :show-inheritance:

Computes the angular velocity (first derivative) of head orientation angles
using finite differences. Returns three arrays corresponding to pitch, roll,
and yaw velocities.